Learn R Programming

qcmetrics (version 1.10.2)

rnadeg: A simple RNA degradation QC for Affymetrix arrays

Description

A simple wrapper function that uses affy's RNA degradation curves and yaqcaffy's actin and GAPDH 3'/5' ratios to generate a simple RNA degradation QcMetrics results. Optionally generates a QC report. See the qcmetrics vignette for an explanation of the function and an example.

Usage

rnadeg(input, status, type,
    reportname = "rnadegradation")

Arguments

input
A character of CEL file names or an instance of class affybatch.
status
A logical of length 2 to set the respective QcMetric's statuses.
type
The type of the report to be generated. Is missing, no report is generated.
reportname
The name of the report.

Value

  • Invisibly return the QcMetrics for the input.

See Also

QcMetric and QcMetrics for details about the QC infrastructure and qcReport for information about the report generation.