Learn R Programming

qcmetrics (version 1.10.2)

QcMetadata-class: The "QcMetadata" class

Description

The QcMetadata class is a simple interface to metadata. The objects can be displayed with show for a summary and print for the content.

Arguments

Objects from the Class

Objects can be created by calls of the form QcMetadata(...).

Examples

Run this code
QcMetadata(metadata =
           list(name = "John Doe",
                lab = "Big Lab in Big Uni"))
## less typing
qmd <- QcMetadata(list(name = "John Doe",
                       lab = "Big Lab in Big Uni"))
mdata(qmd)
show(qmd)
print(qmd)

Run the code above in your browser using DataLab